--------------------------------------------------------------------------------
-- copyright notice:
--------------------------------------------------------------------------------
-- copyright (c) 2007 by
--
-- CESYS GmbH / GERMANY
--
-- http://www.cesys.com
--------------------------------------------------------------------------------
-- author:
--------------------------------------------------------------------------------
-- Stefan Fischer <stefan.fischer@cesys.com>
--------------------------------------------------------------------------------
-- license:
--------------------------------------------------------------------------------
-- THIS SOURCECODE IS NOT FREE! IT IS FOR USE TOGETHER WITH THE CESYS EFM01
-- USB CARD (ARTICLE-NR.: C1050-4107) ONLY! YOU ARE NOT ALLOWED TO MODIFY AND
-- DISTRIBUTE OR USE IT WITH ANY OTHER HARDWARE, SOFTWARE OR ANY OTHER KIND OF
-- ASIC OR PROGRAMMABLE LOGIC DESIGN WITHOUT THE EXPLICIT PERMISSION OF THE
-- COPYRIGHT HOLDER!
--------------------------------------------------------------------------------
-- disclaimer of warranty:
--------------------------------------------------------------------------------
-- THIS SOURCECODE IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
-- THERE IS NO WARRANTY OR SUPPORT FOR THIS SOURCECODE. THE COPYRIGHT HOLDER 
-- PROVIDES THIS SOURCECODE "AS IS" WITHOUT WARRANTY OF ANY KIND,
-- EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
-- WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-- THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THIS SOURCECODE IS WITH
-- YOU. SHOULD THIS SOURCECODE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL 
-- NECESSARY SERVICING, REPAIR OR CORRECTION.
--
-- IN NO EVENT WILL THE COPYRIGHT HOLDER BE LIABLE TO YOU FOR DAMAGES, INCLUDING
-- ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE
-- USE OR INABILITY TO USE THIS SOURCECODE (INCLUDING BUT NOT LIMITED TO LOSS OF
-- DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD 
-- PARTIES OR A FAILURE OF THIS SOURCECODE TO OPERATE WITH ANY OTHER
-- SOFTWARE-PROGRAMS, HARDWARE-CIRCUITS OR ANY OTHER KIND OF ASIC OR
-- PROGRAMMABLE LOGIC DESIGN), EVEN IF THE COPYRIGHT HOLDER HAS BEEN ADVISED OF 
-- THE POSSIBILITY OF SUCH DAMAGES.
--------------------------------------------------------------------------------


library IEEE;
use IEEE.STD_LOGIC_1164.all;

use work.wishbone.all;


entity wb_sl_speedtest is
  generic
  (
    nr_of_irqiports : positive := 1;
    nr_of_irqoports : positive := 1;
    nr_of_dbgports : positive := 1
  );
  port
  (
    SYSCON_I : in rec_syscon_port;
    MASTER_I : in rec_master_port;
    SLAVE_O : out rec_slave_port;

    IRQ_I : in std_logic_vector((nr_of_irqiports-1) downto 0);
    IRQ_O : out std_logic_vector((nr_of_irqoports-1) downto 0);
    
    debug : inout std_logic_vector((nr_of_dbgports-1) downto 0)
  );
end wb_sl_speedtest;


architecture RTL of wb_sl_speedtest is

  signal wishbone : rec_wishbone_signal := wishbone_default;

  signal irqi : std_logic_vector((nr_of_irqiports-1) downto 0) := (others => '0');
  signal irqo : std_logic_vector((nr_of_irqoports-1) downto 0) := (others => '0');

begin

  -- connect ports to internal signals
  ------------------------------------
  
  -- ports of WISHBONE bus
  wishbone.syscon <= SYSCON_I;
  wishbone.master <= MASTER_I;
  SLAVE_O <= wishbone.slave;

  -- ports of interrupt bus
  irqi <= IRQ_I;
  IRQ_O <= irqo;
  
  debug <=
  (
    others => 'Z'
  );

  -- architecture implementation
  ------------------------------

  -- WISHBONE handshake acknowledge response
  wishbone.slave.ack <= wishbone.master.cyc and wishbone.master.stb;
  
  process(wishbone)
  begin
    if wishbone.syscon.clk'event and wishbone.syscon.clk = '1' then
      -- last value transfered is stored for simple loopback test
      if (wishbone.master.cyc and wishbone.master.stb and wishbone.master.we) = '1' then
        wishbone.slave.dat <= wishbone.master.dat;
      end if;
    end if;
  end process;

end RTL;