--------------------------------------------------------------------------------
-- copyright notice:
--------------------------------------------------------------------------------
-- copyright (c) 2007 by
--
-- CESYS GmbH / GERMANY
--
-- http://www.cesys.com
--------------------------------------------------------------------------------
-- author:
--------------------------------------------------------------------------------
-- Stefan Fischer <stefan.fischer@cesys.com>
--------------------------------------------------------------------------------
-- license:
--------------------------------------------------------------------------------
-- THIS SOURCECODE IS NOT FREE! IT IS FOR USE TOGETHER WITH THE CESYS EFM01
-- USB CARD (ARTICLE-NR.: C1050-4107) ONLY! YOU ARE NOT ALLOWED TO MODIFY AND
-- DISTRIBUTE OR USE IT WITH ANY OTHER HARDWARE, SOFTWARE OR ANY OTHER KIND OF
-- ASIC OR PROGRAMMABLE LOGIC DESIGN WITHOUT THE EXPLICIT PERMISSION OF THE
-- COPYRIGHT HOLDER!
--------------------------------------------------------------------------------
-- disclaimer of warranty:
--------------------------------------------------------------------------------
-- THIS SOURCECODE IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
-- THERE IS NO WARRANTY OR SUPPORT FOR THIS SOURCECODE. THE COPYRIGHT HOLDER 
-- PROVIDES THIS SOURCECODE "AS IS" WITHOUT WARRANTY OF ANY KIND,
-- EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
-- WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-- THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THIS SOURCECODE IS WITH
-- YOU. SHOULD THIS SOURCECODE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL 
-- NECESSARY SERVICING, REPAIR OR CORRECTION.
--
-- IN NO EVENT WILL THE COPYRIGHT HOLDER BE LIABLE TO YOU FOR DAMAGES, INCLUDING
-- ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE
-- USE OR INABILITY TO USE THIS SOURCECODE (INCLUDING BUT NOT LIMITED TO LOSS OF
-- DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD 
-- PARTIES OR A FAILURE OF THIS SOURCECODE TO OPERATE WITH ANY OTHER
-- SOFTWARE-PROGRAMS, HARDWARE-CIRCUITS OR ANY OTHER KIND OF ASIC OR
-- PROGRAMMABLE LOGIC DESIGN), EVEN IF THE COPYRIGHT HOLDER HAS BEEN ADVISED OF 
-- THE POSSIBILITY OF SUCH DAMAGES.
--------------------------------------------------------------------------------


library IEEE;
use IEEE.STD_LOGIC_1164.all;

use work.wishbone.all;


entity wb_syscon is
  generic
  (
    nr_of_dbgports : positive := 1
  );
  port
  (
    SYSCON_O : out rec_syscon_port;
    
    sys_rst_i : in std_logic;
    sys_clk_i : in std_logic;

    debug : inout std_logic_vector((nr_of_dbgports-1) downto 0)
  );
end wb_syscon;


architecture RTL of wb_syscon is

  signal syscon : rec_syscon_port := syscon_default;

  signal sys_rst : std_logic := '1';
  signal sys_clk : std_logic := '0';

begin

  -- connect ports to internal signals
  ------------------------------------

  SYSCON_O <= syscon;
  
  sys_rst <= sys_rst_i;
  sys_clk <= sys_clk_i;

  debug <=
  (
    others => 'Z'
  );
  
  -- architecture implementation
  ------------------------------
  
  -- simple route-through of system signals, because clock-management/-deskew
  -- is done externally
  syscon.rst <= sys_rst;
  syscon.clk <= sys_clk;

end RTL;